/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ProgressBarBase } from '../common/progressbar-base';
import { ElementRef, Renderer2 } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI ChunkProgressBar component for Angular]({% slug overview_chunkprogressbar %}).
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 *
 * @Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chunkprogressbar
 *       [value]="progressValue"
 *       [chunkCount]="8">
 *     </kendo-chunkprogressbar>
 *   `
 * })
 * export class AppComponent {
 *   public progressValue: number = 40;
 * }
 * ```
 *
 * @remarks
 * Supported children components are: {@link ProgressBarCustomMessagesComponent}
 */
export declare class ChunkProgressBarComponent extends ProgressBarBase {
    localization: LocalizationService;
    elem: ElementRef;
    renderer: Renderer2;
    chunkClass: boolean;
    /**
     * Sets the number of chunks into which the ChunkProgressBar will be split.
     *
     * @default 5
     */
    chunkCount: number;
    /**
     * @hidden
     */
    get chunks(): boolean[];
    /**
     * Sets the CSS styles that will be rendered on the full chunk elements ([see example]({% slug chunkprogressbar_appearance %})).
     * Supports the type of values that [`ngStyle`](link:site.data.urls.angular['ngstyleapi']) supports.
     */
    progressCssStyle: {
        [key: string]: any;
    };
    /**
     * Sets the CSS classes that will be rendered on the full chunk elements ([see example]({% slug chunkprogressbar_appearance %})).
     * Supports the type of values that [`ngClass`](link:site.data.urls.angular['ngclassapi']) supports.
     */
    progressCssClass: string | string[] | Set<string> | {
        [key: string]: string;
    };
    /**
     * Sets the CSS styles that will be rendered on the empty chunk elements ([see example]({% slug chunkprogressbar_appearance %})).
     * Supports the type of values that [`ngStyle`](link:site.data.urls.angular['ngstyleapi']) supports.
     */
    emptyCssStyle: {
        [key: string]: string;
    };
    /**
     * Sets the CSS classes that will be rendered on the empty chunk elements ([see example]({% slug chunkprogressbar_appearance %})).
     * Supports the type of values that [`ngClass`](link:site.data.urls.angular['ngclassapi']) supports.
     */
    emptyCssClass: string | string[] | Set<string> | {
        [key: string]: any;
    };
    /**
     * @hidden
     */
    get chunkSizePercentage(): number;
    /**
     * @hidden
     */
    get orientationStyles(): {
        width: string;
        height: string;
    };
    private _orientationStyles;
    /**
     * @hidden
     */
    constructor(localization: LocalizationService, elem: ElementRef, renderer: Renderer2);
    static ɵfac: i0.ɵɵFactoryDeclaration<ChunkProgressBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChunkProgressBarComponent, "kendo-chunkprogressbar", ["kendoChunkProgressBar"], { "chunkCount": { "alias": "chunkCount"; "required": false; }; "progressCssStyle": { "alias": "progressCssStyle"; "required": false; }; "progressCssClass": { "alias": "progressCssClass"; "required": false; }; "emptyCssStyle": { "alias": "emptyCssStyle"; "required": false; }; "emptyCssClass": { "alias": "emptyCssClass"; "required": false; }; }, {}, never, never, true, never>;
}
