/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChunkProgressBarComponent } from "./chunk/chunk-progressbar.component";
import { CircularProgressbarCenterTemplateDirective } from "./circularprogressbar/center-template.directive";
import { CircularProgressBarComponent } from "./circularprogressbar/circular-progressbar.component";
import { ProgressBarCustomMessagesComponent } from "./common/localization/custom-messages.component";
import { ProgressBarComponent } from "./progressbar.component";
/**
 * Use this utility array to access all ChunkProgressBar-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { KENDO_CHUNKPROGRESSBAR } from '@progress/kendo-angular-progressbar';
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_CHUNKPROGRESSBAR],
 *   template: `<kendo-chunkprogressbar [value]="50"></kendo-chunkprogressbar>`,
 * })
 * export class MyComponent {}
 * ```
 */
export declare const KENDO_CHUNKPROGRESSBAR: readonly [typeof ChunkProgressBarComponent, typeof ProgressBarCustomMessagesComponent];
/**
 * Use this utility array to access all CircularProgressbar-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { KENDO_CIRCULARPROGRESSBAR } from '@progress/kendo-angular-progressbar';
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_CIRCULARPROGRESSBAR],
 *   template: `<kendo-circularprogressbar [value]="75"></kendo-circularprogressbar>`,
 * })
 * export class MyComponent {}
 * ```
 */
export declare const KENDO_CIRCULARPROGRESSBAR: readonly [typeof CircularProgressbarCenterTemplateDirective, typeof CircularProgressBarComponent, typeof ProgressBarCustomMessagesComponent];
/**
 * Use this utility array to access all ProgressBar-related components and directives in a standalone Angular component.
 *
  * @example
 * ```typescript
 * import { KENDO_PROGRESSBAR } from '@progress/kendo-angular-progressbar';
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_PROGRESSBAR],
 *   template: `<kendo-progressbar [value]="75"></kendo-progressbar>`,
 * })
 * export class MyComponent {}
 * ```
 */
export declare const KENDO_PROGRESSBAR: readonly [typeof ProgressBarComponent, typeof ProgressBarCustomMessagesComponent];
/**
 * Use this utility array all `@progress/kendo-angular-progressbar`-related components and directives.
 * @example
 * ```typescript
 * import { KENDO_PROGRESSBARS } from '@progress/kendo-angular-progressbar';
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_PROGRESSBARS],
 *   template: `
 *     <kendo-progressbar [value]="75"></kendo-progressbar>
 *     <kendo-circularprogressbar [value]="75"></kendo-circularprogressbar>
 *   `,
 * })
 * export class MyComponent {}
 * ```
 */
export declare const KENDO_PROGRESSBARS: readonly [typeof ChunkProgressBarComponent, typeof ProgressBarCustomMessagesComponent, typeof CircularProgressbarCenterTemplateDirective, typeof CircularProgressBarComponent, typeof ProgressBarCustomMessagesComponent, typeof ProgressBarComponent, typeof ProgressBarCustomMessagesComponent];
