/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LabelType } from './label-type';
import { LabelFn } from './label-fn-type';
import { LabelPosition } from './label-position';
/**
 * Represents the settings of the label that shows the progress status of the ProgressBar.
 *
 */
export interface LabelSettings {
    /**
     * Shows or hides the label for the progress status.
     */
    visible?: boolean;
    /**
     * Sets the position of the progress status label.
     * @default 'end'
     */
    position?: LabelPosition;
    /**
     * Sets the format for rendering the value in the label.
     * The supported preset types are `value` (default) and `percent`.
     * You can also provide a callback that exposes the current value and returns
     * the formatted string to display in the label
     * ([see example]({% slug progressbar_label %}#toc-using-a-formatting-function)).
     *
     * @default 'value'
     */
    format?: LabelType | LabelFn;
}
